==> joplin_3.1.20+ds.orig.tar.xz: joplin-3.1.20/readme/apps/teams.md <==
# Joplin Cloud Teams feature

Joplin Cloud's Teams functionality enables the efficient administration of multiple users within a team. Serving as a centralized hub, it provides an overview of all users within your organisations, facilitating easy addition or removal of members. Billing is consolidated, ensuring a single monthly or yearly invoice, based on your chosen plan. The billing is automatically adjusted in accordance with the number of team members.

## Terminology

- The **team admin account** is main account for a team. This account is only for managing users and billing. You cannot synchronise data with it.
- **Member account**s are added to a team by the **team admin** account. These accounts can sync data and collaborate with other member accounts on the same team.

## Setting up your team

To setup your Team, open the [Team tab](https://joplincloud.com/teams/me) at the top of the page. From there you can set the number of members in your team or change the team name.

## Inviting members to your team

To invite a member to your team, go to the [Members tag](https://joplincloud.com/teams/me/users). From there, add one or multiple emails (separated by commas) and click "Invite members".

These members will receive an email with a link they will need to follow in order to accept the invitation. You can see which members have accepted the invitation or not in the Members table on that same page.

## Removing a member from your team

To remove a member from your team click on the Profile icon (👤) for that user, then click on "Remove user".

## Adding yourself to the team

The team admin account is only for managing users and billing. To collaborate with the other members of your team, add yourself as a member using a different email address.

==> joplin_3.6.2+ds.orig.tar.xz: joplin-3.6.2/readme/apps/teams.md <==
# Joplin Cloud Teams feature

Joplin Cloud's Teams functionality enables the efficient administration of multiple users within a team. Serving as a centralized hub, it provides an overview of all users within your organisations, facilitating easy addition or removal of members. Billing is consolidated, ensuring a single monthly or yearly invoice, based on your chosen plan. The billing is automatically adjusted in accordance with the number of team members.

## Terminology

- The **team admin account** is main account for a team. This account is only for managing users and billing. You cannot synchronise data with it.
- **Member account**s are added to a team by the **team admin** account. These accounts can sync data and collaborate with other member accounts on the same team.

## Setting up your team

To setup your Team, open the [Team tab](https://joplincloud.com/teams/me) at the top of the page. From there you can set the number of members in your team or change the team name.

## Inviting members to your team

To invite a member to your team, go to the [Members tag](https://joplincloud.com/teams/me/users). From there, add one or multiple emails (separated by commas) and click "Invite members".

These members will receive an email with a link they will need to follow in order to accept the invitation. You can see which members have accepted the invitation or not in the Members table on that same page.

## Removing a member from your team

To remove a member from your team click on the Profile icon (👤) for that user, then click on "Remove user".

## Adding yourself to the team

The team admin account is only for managing users and billing. To collaborate with the other members of your team, add yourself as a member using a different email address.

## Migrating to a Team account

If you already have a Basic or Pro account, it is not currently possible to migrate your data to a Team account, as they work very differently.

You can however follow these steps to manually migrate your data to a Team account:

- Open the Joplin desktop app
- Click Synchronise and wait for it to complete
- Export all your notes as JEX (File => Export => JEX)
- Create a new profile (File => Switch profile)
- Import your JEX file
- Cancel your current Joplin Cloud subscription
- Open a new Joplin Cloud Team subscription
- Synchronise your new profile with this new subscription
